# Generated by ariadne-codegen
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import CouponFragment


class CreateCoupon(BaseModel):
    create_one_coupon: "CreateCouponCreateOneCoupon" = Field(alias="createOneCoupon")


class CreateCouponCreateOneCoupon(CouponFragment):
    pass


CreateCoupon.model_rebuild()
