# Generated by ariadne-codegen
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SlimSubscriptionFragment


class TransferSubscriptionToResource(BaseModel):
    transfer_subscription_to_resource: "TransferSubscriptionToResourceTransferSubscriptionToResource" = Field(
        alias="transferSubscriptionToResource"
    )


class TransferSubscriptionToResourceTransferSubscriptionToResource(
    SlimSubscriptionFragment
):
    pass


TransferSubscriptionToResource.model_rebuild()
